import { __decorate, __param } from 'tslib';
import { Optional, Injectable, NgModule } from '@angular/core';
import { tap } from 'rxjs/operators';

var LogLevel;
(function (LogLevel) {
    LogLevel[LogLevel["INFO"] = 0] = "INFO";
    LogLevel[LogLevel["DEBUG"] = 1] = "DEBUG";
    LogLevel[LogLevel["WARNING"] = 2] = "WARNING";
    LogLevel[LogLevel["ERROR"] = 3] = "ERROR";
})(LogLevel || (LogLevel = {}));
class AbstractNgxFancyLoggerService {
}
class LoggerConfig {
    constructor() {
        this.showTime = true;
        this.logLevel = LogLevel.INFO;
        this.showEmoji = true;
        this.showLabel = true;
        this.disableLogs = false;
        this.levelColor = {};
        this.levelEmoji = {};
    }
}
const DEFAULT_LEVEL_COLORS = {
    [LogLevel.INFO]: 'steelblue',
    [LogLevel.DEBUG]: 'black',
    [LogLevel.WARNING]: 'orange',
    [LogLevel.ERROR]: 'red'
};
const DEFAULT_EMOJIS = {
    [LogLevel.INFO]: '🐬',
    [LogLevel.DEBUG]: '👨‍💻',
    [LogLevel.WARNING]: '⚡',
    [LogLevel.ERROR]: '😨'
};
let NgxFancyLoggerService = class NgxFancyLoggerService {
    constructor(loggerConfig) {
        this.loggerConfig = loggerConfig;
        this.DEFAULT_CONFIG = new LoggerConfig();
        this.levelPrefix = {};
        this.showTime = () => {
            return this.config.showTime ? ` > ${new Date().toLocaleString()}` : '';
        };
        this.getStyles = (level) => `color:white;
                                            background-color:${this.config.levelColor[level] || DEFAULT_LEVEL_COLORS[level]};
                                            padding: 0px 2px;
                                            border-radius: 2px`;
        /** RxJS Debug Operator to generate Log */
        this.debugOperator = (message, logLevel = LogLevel.DEBUG) => tap(data => {
            this.log(logLevel, message || '', data);
        });
        this.config = this.DEFAULT_CONFIG;
        this.updateConfig(loggerConfig);
    }
    setPrefix() {
        if (this.config.disableLogs) {
            return;
        }
        for (const key in LogLevel) {
            if (!isNaN(Number(key))) {
                let prefix = this.config.showEmoji ? this.config.levelEmoji[key] || DEFAULT_EMOJIS[key] : '';
                if (this.config.showLabel) {
                    prefix += LogLevel[key];
                }
                this.levelPrefix[key] = prefix;
            }
        }
    }
    /** Common Log Method */
    log(level, ...args) {
        let method = 'log';
        switch (level) {
            case LogLevel.WARNING:
                method = 'warn';
                break;
            case LogLevel.ERROR:
                method = 'error';
                break;
        }
        if (this.config.disableLogs || (level < this.config.logLevel)) {
            return;
        }
        console[method](`%c${this.levelPrefix[level]}${this.showTime()}`, this.getStyles(level), ...args);
    }
    /** Update configuration, it will override configuration done through forRoot or Default Config */
    updateConfig(loggerConfig) {
        this.config = Object.assign(Object.assign({}, this.config), loggerConfig);
        this.setPrefix();
    }
    /** Reset to Default Configuration */
    resetConfig() {
        this.config = this.DEFAULT_CONFIG;
        this.setPrefix();
    }
    /** Display INFO level log */
    info(...args) {
        this.log(LogLevel.INFO, ...args);
    }
    /** Display DEBUG level log */
    debug(...args) {
        this.log(LogLevel.DEBUG, ...args);
    }
    /** Display WARNING Level log */
    warning(...args) {
        this.log(LogLevel.WARNING, ...args);
    }
    /** Display ERROR level log */
    error(...args) {
        this.log(LogLevel.ERROR, ...args);
    }
    /** Display Header on Console, You can configure color and fontSize of header */
    header(title, config = {}) {
        const styles = `font-size: ${config.fontSize || 20}px; color:${config.color || 'steelblue'};   text-shadow: #ddd 2px 2px 2px`;
        console.log(`%c${title}`, styles);
    }
};
NgxFancyLoggerService.ctorParameters = () => [
    { type: LoggerConfig, decorators: [{ type: Optional }] }
];
NgxFancyLoggerService = __decorate([
    Injectable(),
    __param(0, Optional())
], NgxFancyLoggerService);

var NgxFancyLoggerModule_1;
let NgxFancyLoggerModule = NgxFancyLoggerModule_1 = class NgxFancyLoggerModule {
    static forRoot(config) {
        return {
            ngModule: NgxFancyLoggerModule_1,
            providers: [
                { provide: LoggerConfig, useValue: config || {} },
                NgxFancyLoggerService
            ]
        };
    }
};
NgxFancyLoggerModule = NgxFancyLoggerModule_1 = __decorate([
    NgModule({
        imports: [],
        providers: [NgxFancyLoggerService]
    })
], NgxFancyLoggerModule);

/*
 * Public API Surface of ngx-fancy-logger
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AbstractNgxFancyLoggerService, LogLevel, LoggerConfig, NgxFancyLoggerModule, NgxFancyLoggerService };
//# sourceMappingURL=ngx-fancy-logger.js.map
